from enum import Enum


class PssListSeasonType(str, Enum):
    MULTI_YEAR_HISTORICAL = "MULTI_YEAR_HISTORICAL"
    ONE_OFF = "ONE_OFF"
    PRESEASON = "PRESEASON"
    SEASON = "SEASON"
    TOURNAMENT = "TOURNAMENT"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class StandingListGroupingStagePool(str, Enum):
    OVERALL = "OVERALL"
    STAGE = "STAGE"
    STAGEPOOL = "STAGEPOOL"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.organization_model_region_type import OrganizationModelRegionType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.images_model import ImagesModel


T = TypeVar("T", bound="OrganizationModel")


@_attrs_define
class OrganizationModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: b1a23.
        abbreviation_local (Union[None, Unset, str]): An abbreviation/short name in the
            [local](#section/Introduction/Character-Sets-and-Names) language Example: NFA.
        name_local (Union[Unset, str]): The name of the organization in the [local](#section/Introduction/Character-
            Sets-and-Names) language Example: Test name local.
        abbreviation_latin (Union[None, Unset, str]): An abbreviation/short name in
            [latin](#section/Introduction/Character-Sets-and-Names) characters Example: NFA.
        name_latin (Union[None, Unset, str]): The name of the organization in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Test name latin .
        country_code (Union[None, Unset, str]): Country code of the organization. We recommend you use ISO-3166-1:alpha3
            (upper case) values where available. Example: USA.
        region_type (Union[Unset, OrganizationModelRegionType]): How geographically relevant is this organization
            >- `INTERNATIONAL` Multiple countries
            >- `INTERSTATE` Cross state
            >- `LOCAL` Local area
            >- `NATIONAL` One country
            >- `STATE` One state
             Example: STATE.
        default_locale (Union[Unset, str]): The locale of the video Example: fr-FR.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        images (Union[Unset, list['ImagesModel']]):
    """

    organization_id: Union[Unset, str] = UNSET
    abbreviation_local: Union[None, Unset, str] = UNSET
    name_local: Union[Unset, str] = UNSET
    abbreviation_latin: Union[None, Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    country_code: Union[None, Unset, str] = UNSET
    region_type: Union[Unset, OrganizationModelRegionType] = UNSET
    default_locale: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        organization_id = self.organization_id

        abbreviation_local: Union[None, Unset, str]
        if isinstance(self.abbreviation_local, Unset):
            abbreviation_local = UNSET
        else:
            abbreviation_local = self.abbreviation_local

        name_local = self.name_local

        abbreviation_latin: Union[None, Unset, str]
        if isinstance(self.abbreviation_latin, Unset):
            abbreviation_latin = UNSET
        else:
            abbreviation_latin = self.abbreviation_latin

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        country_code: Union[None, Unset, str]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        else:
            country_code = self.country_code

        region_type: Union[Unset, str] = UNSET
        if not isinstance(self.region_type, Unset):
            region_type = self.region_type.value

        default_locale = self.default_locale

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if abbreviation_local is not UNSET:
            field_dict["abbreviationLocal"] = abbreviation_local
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if abbreviation_latin is not UNSET:
            field_dict["abbreviationLatin"] = abbreviation_latin
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code
        if region_type is not UNSET:
            field_dict["regionType"] = region_type
        if default_locale is not UNSET:
            field_dict["defaultLocale"] = default_locale
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.images_model import ImagesModel

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        def _parse_abbreviation_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_local = _parse_abbreviation_local(d.pop("abbreviationLocal", UNSET))

        name_local = d.pop("nameLocal", UNSET)

        def _parse_abbreviation_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviation_latin = _parse_abbreviation_latin(d.pop("abbreviationLatin", UNSET))

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_country_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))

        _region_type = d.pop("regionType", UNSET)
        region_type: Union[Unset, OrganizationModelRegionType]
        if isinstance(_region_type, Unset):
            region_type = UNSET
        else:
            region_type = OrganizationModelRegionType(_region_type)

        default_locale = d.pop("defaultLocale", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        organization_model = cls(
            organization_id=organization_id,
            abbreviation_local=abbreviation_local,
            name_local=name_local,
            abbreviation_latin=abbreviation_latin,
            name_latin=name_latin,
            country_code=country_code,
            region_type=region_type,
            default_locale=default_locale,
            updated=updated,
            added=added,
            images=images,
        )

        return organization_model



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.head_to_head_entity_model_competition import HeadToHeadEntityModelCompetition
    from ..models.head_to_head_entity_model_fixture import HeadToHeadEntityModelFixture
    from ..models.head_to_head_entity_model_organization import HeadToHeadEntityModelOrganization
    from ..models.head_to_head_entity_model_season import HeadToHeadEntityModelSeason


T = TypeVar("T", bound="HeadToHeadEntityModel")


@_attrs_define
class HeadToHeadEntityModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, HeadToHeadEntityModelOrganization]): The organization that this head_to_head_entity
            belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, HeadToHeadEntityModelFixture]): The match
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, HeadToHeadEntityModelSeason]): The season linked to this record
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, HeadToHeadEntityModelCompetition]): The competition that this season belongs to
    """

    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "HeadToHeadEntityModelOrganization"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "HeadToHeadEntityModelFixture"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "HeadToHeadEntityModelSeason"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "HeadToHeadEntityModelCompetition"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.head_to_head_entity_model_competition import HeadToHeadEntityModelCompetition
        from ..models.head_to_head_entity_model_fixture import HeadToHeadEntityModelFixture
        from ..models.head_to_head_entity_model_organization import HeadToHeadEntityModelOrganization
        from ..models.head_to_head_entity_model_season import HeadToHeadEntityModelSeason

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, HeadToHeadEntityModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = HeadToHeadEntityModelOrganization.from_dict(_organization)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, HeadToHeadEntityModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = HeadToHeadEntityModelFixture.from_dict(_fixture)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, HeadToHeadEntityModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = HeadToHeadEntityModelSeason.from_dict(_season)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, HeadToHeadEntityModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = HeadToHeadEntityModelCompetition.from_dict(_competition)

        head_to_head_entity_model = cls(
            organization_id=organization_id,
            organization=organization,
            fixture_id=fixture_id,
            fixture=fixture,
            season_id=season_id,
            season=season,
            competition_id=competition_id,
            competition=competition,
        )

        return head_to_head_entity_model



from enum import Enum


class RolesListNonFixturesRole(str, Enum):
    ASSISTANT_REFEREE_1 = "ASSISTANT_REFEREE_1"
    ASSISTANT_REFEREE_2 = "ASSISTANT_REFEREE_2"
    CAPTAIN = "CAPTAIN"
    CAPTAIN_VICE = "CAPTAIN_VICE"
    CEO = "CEO"
    CLUB_IT_OFFICER = "CLUB_IT_OFFICER"
    CLUB_OFFICIAL = "CLUB_OFFICIAL"
    CLUB_OFFICIAL_ASSISTANT = "CLUB_OFFICIAL_ASSISTANT"
    COACH = "COACH"
    COACH_ASSISTANT = "COACH_ASSISTANT"
    COACH_ASSISTANT_HEAD = "COACH_ASSISTANT_HEAD"
    COACH_ASSOCIATE_HEAD = "COACH_ASSOCIATE_HEAD"
    COACH_DEVELOPMENT = "COACH_DEVELOPMENT"
    COACH_HEAD = "COACH_HEAD"
    COACH_HEAD_INTERIM = "COACH_HEAD_INTERIM"
    COACH_OTHER = "COACH_OTHER"
    COACH_SC = "COACH_SC"
    COACH_SENIOR = "COACH_SENIOR"
    COACH_SPECIALIST = "COACH_SPECIALIST"
    COMMISSIONER = "COMMISSIONER"
    COMMITTEE = "COMMITTEE"
    CREW_CHIEF = "CREW_CHIEF"
    DELEGATE = "DELEGATE"
    DIRECTOR = "DIRECTOR"
    DOCTOR = "DOCTOR"
    GENERAL = "GENERAL"
    GROUNDSKEEPER = "GROUNDSKEEPER"
    JUDGE_SCORING = "JUDGE_SCORING"
    JUDGE_TIMING = "JUDGE_TIMING"
    LIAISON_OFFICER = "LIAISON_OFFICER"
    MANAGER = "MANAGER"
    MATCH_LIAISON = "MATCH_LIAISON"
    MATCH_OFFICIAL = "MATCH_OFFICIAL"
    MATCH_SUPERVISOR = "MATCH_SUPERVISOR"
    MEDIA_OFFICER = "MEDIA_OFFICER"
    MEDICAL_STAFF = "MEDICAL_STAFF"
    OFFICE_STAFF = "OFFICE_STAFF"
    OFFICIAL_A = "OFFICIAL_A"
    OFFICIAL_B = "OFFICIAL_B"
    OFFICIAL_C = "OFFICIAL_C"
    OFFICIAL_D = "OFFICIAL_D"
    OFFICIAL_E = "OFFICIAL_E"
    OTHER = "OTHER"
    PHYSIOTHERAPIST = "PHYSIOTHERAPIST"
    PLAYER_CONTRACT_MANAGER = "PLAYER_CONTRACT_MANAGER"
    PRESIDENT = "PRESIDENT"
    PRESIDENT_VICE = "PRESIDENT_VICE"
    REFEREE = "REFEREE"
    REFEREE_ASSISTANT = "REFEREE_ASSISTANT"
    REFEREE_ASSISTANT_RESERVE = "REFEREE_ASSISTANT_RESERVE"
    REFEREE_LIAISON = "REFEREE_LIAISON"
    REFEREE_OBSERVER = "REFEREE_OBSERVER"
    REFEREE_OBSERVER_LIAISON = "REFEREE_OBSERVER_LIAISON"
    REFEREE_RESERVE = "REFEREE_RESERVE"
    SCOREKEEPER = "SCOREKEEPER"
    SCOREKEEPER_ASSISTANT = "SCOREKEEPER_ASSISTANT"
    SCORER = "SCORER"
    SCORER_ASSISTANT = "SCORER_ASSISTANT"
    SCOUT_1 = "SCOUT_1"
    SCOUT_2 = "SCOUT_2"
    SCOUT_3 = "SCOUT_3"
    SCOUT_SUPERVISOR = "SCOUT_SUPERVISOR"
    SECRETARY = "SECRETARY"
    SHOT_CLOCK_OPERATOR = "SHOT_CLOCK_OPERATOR"
    SPORT_DIRECTOR = "SPORT_DIRECTOR"
    STATISTICIAN = "STATISTICIAN"
    TEAM_COORDINATOR = "TEAM_COORDINATOR"
    TECHNICAL_DELEGATE = "TECHNICAL_DELEGATE"
    TECHNICAL_DELEGATE_ASSISTANT = "TECHNICAL_DELEGATE_ASSISTANT"
    TECHNICAL_OFFICIAL = "TECHNICAL_OFFICIAL"
    TIMEKEEPER = "TIMEKEEPER"
    TIMER = "TIMER"
    TRAINER = "TRAINER"
    TRAINER_ASSISTANT = "TRAINER_ASSISTANT"
    TRANSLATOR = "TRANSLATOR"
    TREASURER = "TREASURER"
    UMPIRE = "UMPIRE"
    UMPIRE_1 = "UMPIRE_1"
    UMPIRE_2 = "UMPIRE_2"
    UMPIRE_MANAGER = "UMPIRE_MANAGER"
    UMPIRE_RESERVE = "UMPIRE_RESERVE"
    UMPIRE_VIDEO = "UMPIRE_VIDEO"
    VIDEO_TECHNICIAN = "VIDEO_TECHNICIAN"
    YOUTH_COORDINATOR = "YOUTH_COORDINATOR"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.team_model_age_group_type_1 import TeamModelAgeGroupType1
from ..models.team_model_age_group_type_2_type_1 import TeamModelAgeGroupType2Type1
from ..models.team_model_age_group_type_3_type_1 import TeamModelAgeGroupType3Type1
from ..models.team_model_discipline_type_1 import TeamModelDisciplineType1
from ..models.team_model_discipline_type_2_type_1 import TeamModelDisciplineType2Type1
from ..models.team_model_discipline_type_3_type_1 import TeamModelDisciplineType3Type1
from ..models.team_model_gender_type_1 import TeamModelGenderType1
from ..models.team_model_gender_type_2_type_1 import TeamModelGenderType2Type1
from ..models.team_model_gender_type_3_type_1 import TeamModelGenderType3Type1
from ..models.team_model_standard_type_1 import TeamModelStandardType1
from ..models.team_model_standard_type_2_type_1 import TeamModelStandardType2Type1
from ..models.team_model_standard_type_3_type_1 import TeamModelStandardType3Type1
from ..models.team_model_status import TeamModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.images_model import ImagesModel
    from ..models.team_model_additional_names import TeamModelAdditionalNames
    from ..models.team_model_colors import TeamModelColors
    from ..models.team_model_contact_details import TeamModelContactDetails
    from ..models.team_model_entity_additional_details import TeamModelEntityAdditionalDetails
    from ..models.team_model_entity_group import TeamModelEntityGroup
    from ..models.team_model_organization import TeamModelOrganization
    from ..models.team_model_social_media import TeamModelSocialMedia
    from ..models.team_model_team_address import TeamModelTeamAddress
    from ..models.team_model_team_historical_name import TeamModelTeamHistoricalName


T = TypeVar("T", bound="TeamModel")


@_attrs_define
class TeamModel:
    """
    Attributes:
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, TeamModelOrganization]): The organization that this team belongs to
        entity_group_id (Union[None, UUID, Unset]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, TeamModelEntityGroup]): The club that this team belongs to
        international_reference (Union[None, Unset, str]): The international reference for this team given by the sport
            governing body Example: CA3243-3.
        status (Union[Unset, TeamModelStatus]): Status
            >- `ACTIVE` Active
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
             Example: ACTIVE.
        name_full_local (Union[Unset, str]): The full name of the team in the [local](#section/Introduction/Character-
            Sets-and-Names) language Example: Los Angeles Armadillos.
        additional_names (Union[Unset, TeamModelAdditionalNames]):
        name_full_latin (Union[None, Unset, str]): The full name of the team in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Los Angeles Armadillos.
        code_local (Union[None, Unset, str]): The code of the team in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: TEST.
        code_latin (Union[None, Unset, str]): The code of the team in [latin](#section/Introduction/Character-Sets-and-
            Names) characters Example: TEST.
        address (Union['TeamModelTeamAddress', None, Unset]): Street Address for the team
        social (Union['TeamModelSocialMedia', None, Unset]): Social Media contacts
        contacts (Union['TeamModelContactDetails', None, Unset]): Public contact fields
        details (Union['TeamModelEntityAdditionalDetails', None, Unset]): Additional detail fields
        colors (Union[Unset, TeamModelColors]):
        historical_names (Union[None, Unset, list['TeamModelTeamHistoricalName']]): Array of team historical names
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        age_group (Union[None, TeamModelAgeGroupType1, TeamModelAgeGroupType2Type1, TeamModelAgeGroupType3Type1,
            Unset]): The age group of the team
            >- None None
            >- `JUNIOR` Junior
            >- `MASTERS` Masters
            >- `SENIOR` Senior
            >- `UNDER_10` Under 10
            >- `UNDER_11` Under 11
            >- `UNDER_12` Under 12
            >- `UNDER_13` Under 13
            >- `UNDER_14` Under 14
            >- `UNDER_15` Under 15
            >- `UNDER_16` Under 16
            >- `UNDER_17` Under 17
            >- `UNDER_18` Under 18
            >- `UNDER_19` Under 19
            >- `UNDER_20` Under 20
            >- `UNDER_21` Under 21
            >- `UNDER_22` Under 22
            >- `UNDER_23` Under 23
            >- `YOUTH` Youth
             Example: SENIOR.
        gender (Union[None, TeamModelGenderType1, TeamModelGenderType2Type1, TeamModelGenderType3Type1, Unset]): The
            gender of the participants in the team
            >- None None
            >- `FEMALE` Female
            >- `MALE` Male
            >- `MIXED` Mixed
            >- `UNKNOWN` Unknown
             Example: MALE.
        standard (Union[None, TeamModelStandardType1, TeamModelStandardType2Type1, TeamModelStandardType3Type1, Unset]):
            The playing standard of the team
            >- None None
            >- `ELITE` Professional/elite organisation
            >- `FRIENDLY` International Friendly
            >- `GRASS_ROOT` Normal
            >- `INTERNATIONAL` International
            >- `NONCONTINENTAL_CHAMPIONSHIP` Non-continental Championship
            >- `OLYMPIC` Olympics
            >- `REGION` Regional
            >- `TIER2` lesser standard than elite
            >- `TIER3` lesser standard than tier 2
            >- `WORLD_CHAMPIONSHIP` World Championship
            >- `ZONE_CHAMPIONSHIP` International Zone Championship
             Example: ELITE.
        grade (Union[None, Unset, str]): The playing grade of the matches for this team Example: A.
        representing (Union[None, Unset, str]): Who the team was representing Example: AUSTRALIA.
        discipline (Union[None, TeamModelDisciplineType1, TeamModelDisciplineType2Type1, TeamModelDisciplineType3Type1,
            Unset]): Discipline' the team participates in
            >- None None
            >- `INDOOR` Indoor
            >- `OUTDOOR` Outdoor
             Example: INDOOR.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        default_venue_id (Union[None, UUID, Unset]): The unique identifier of the default venue Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        alternate_venue_ids (Union[Unset, list[UUID]]):
        images (Union[Unset, list['ImagesModel']]):
    """

    entity_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "TeamModelOrganization"] = UNSET
    entity_group_id: Union[None, UUID, Unset] = UNSET
    entity_group: Union[Unset, "TeamModelEntityGroup"] = UNSET
    international_reference: Union[None, Unset, str] = UNSET
    status: Union[Unset, TeamModelStatus] = UNSET
    name_full_local: Union[Unset, str] = UNSET
    additional_names: Union[Unset, "TeamModelAdditionalNames"] = UNSET
    name_full_latin: Union[None, Unset, str] = UNSET
    code_local: Union[None, Unset, str] = UNSET
    code_latin: Union[None, Unset, str] = UNSET
    address: Union["TeamModelTeamAddress", None, Unset] = UNSET
    social: Union["TeamModelSocialMedia", None, Unset] = UNSET
    contacts: Union["TeamModelContactDetails", None, Unset] = UNSET
    details: Union["TeamModelEntityAdditionalDetails", None, Unset] = UNSET
    colors: Union[Unset, "TeamModelColors"] = UNSET
    historical_names: Union[None, Unset, list["TeamModelTeamHistoricalName"]] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    age_group: Union[None, TeamModelAgeGroupType1, TeamModelAgeGroupType2Type1, TeamModelAgeGroupType3Type1, Unset] = (
        UNSET
    )
    gender: Union[None, TeamModelGenderType1, TeamModelGenderType2Type1, TeamModelGenderType3Type1, Unset] = UNSET
    standard: Union[None, TeamModelStandardType1, TeamModelStandardType2Type1, TeamModelStandardType3Type1, Unset] = (
        UNSET
    )
    grade: Union[None, Unset, str] = UNSET
    representing: Union[None, Unset, str] = UNSET
    discipline: Union[
        None, TeamModelDisciplineType1, TeamModelDisciplineType2Type1, TeamModelDisciplineType3Type1, Unset
    ] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    default_venue_id: Union[None, UUID, Unset] = UNSET
    alternate_venue_ids: Union[Unset, list[UUID]] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.team_model_contact_details import TeamModelContactDetails
        from ..models.team_model_entity_additional_details import TeamModelEntityAdditionalDetails
        from ..models.team_model_social_media import TeamModelSocialMedia
        from ..models.team_model_team_address import TeamModelTeamAddress

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_group_id: Union[None, Unset, str]
        if isinstance(self.entity_group_id, Unset):
            entity_group_id = UNSET
        elif isinstance(self.entity_group_id, UUID):
            entity_group_id = str(self.entity_group_id)
        else:
            entity_group_id = self.entity_group_id

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        international_reference: Union[None, Unset, str]
        if isinstance(self.international_reference, Unset):
            international_reference = UNSET
        else:
            international_reference = self.international_reference

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        name_full_local = self.name_full_local

        additional_names: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.additional_names, Unset):
            additional_names = self.additional_names.to_dict()

        name_full_latin: Union[None, Unset, str]
        if isinstance(self.name_full_latin, Unset):
            name_full_latin = UNSET
        else:
            name_full_latin = self.name_full_latin

        code_local: Union[None, Unset, str]
        if isinstance(self.code_local, Unset):
            code_local = UNSET
        else:
            code_local = self.code_local

        code_latin: Union[None, Unset, str]
        if isinstance(self.code_latin, Unset):
            code_latin = UNSET
        else:
            code_latin = self.code_latin

        address: Union[None, Unset, dict[str, Any]]
        if isinstance(self.address, Unset):
            address = UNSET
        elif isinstance(self.address, TeamModelTeamAddress):
            address = self.address.to_dict()
        else:
            address = self.address

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, TeamModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        contacts: Union[None, Unset, dict[str, Any]]
        if isinstance(self.contacts, Unset):
            contacts = UNSET
        elif isinstance(self.contacts, TeamModelContactDetails):
            contacts = self.contacts.to_dict()
        else:
            contacts = self.contacts

        details: Union[None, Unset, dict[str, Any]]
        if isinstance(self.details, Unset):
            details = UNSET
        elif isinstance(self.details, TeamModelEntityAdditionalDetails):
            details = self.details.to_dict()
        else:
            details = self.details

        colors: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.colors, Unset):
            colors = self.colors.to_dict()

        historical_names: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.historical_names, Unset):
            historical_names = UNSET
        elif isinstance(self.historical_names, list):
            historical_names = []
            for historical_names_type_0_item_data in self.historical_names:
                historical_names_type_0_item = historical_names_type_0_item_data.to_dict()
                historical_names.append(historical_names_type_0_item)

        else:
            historical_names = self.historical_names

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        age_group: Union[None, Unset, str]
        if isinstance(self.age_group, Unset):
            age_group = UNSET
        elif isinstance(self.age_group, TeamModelAgeGroupType1):
            age_group = self.age_group.value
        elif isinstance(self.age_group, TeamModelAgeGroupType2Type1):
            age_group = self.age_group.value
        elif isinstance(self.age_group, TeamModelAgeGroupType3Type1):
            age_group = self.age_group.value
        else:
            age_group = self.age_group

        gender: Union[None, Unset, str]
        if isinstance(self.gender, Unset):
            gender = UNSET
        elif isinstance(self.gender, TeamModelGenderType1):
            gender = self.gender.value
        elif isinstance(self.gender, TeamModelGenderType2Type1):
            gender = self.gender.value
        elif isinstance(self.gender, TeamModelGenderType3Type1):
            gender = self.gender.value
        else:
            gender = self.gender

        standard: Union[None, Unset, str]
        if isinstance(self.standard, Unset):
            standard = UNSET
        elif isinstance(self.standard, TeamModelStandardType1):
            standard = self.standard.value
        elif isinstance(self.standard, TeamModelStandardType2Type1):
            standard = self.standard.value
        elif isinstance(self.standard, TeamModelStandardType3Type1):
            standard = self.standard.value
        else:
            standard = self.standard

        grade: Union[None, Unset, str]
        if isinstance(self.grade, Unset):
            grade = UNSET
        else:
            grade = self.grade

        representing: Union[None, Unset, str]
        if isinstance(self.representing, Unset):
            representing = UNSET
        else:
            representing = self.representing

        discipline: Union[None, Unset, str]
        if isinstance(self.discipline, Unset):
            discipline = UNSET
        elif isinstance(self.discipline, TeamModelDisciplineType1):
            discipline = self.discipline.value
        elif isinstance(self.discipline, TeamModelDisciplineType2Type1):
            discipline = self.discipline.value
        elif isinstance(self.discipline, TeamModelDisciplineType3Type1):
            discipline = self.discipline.value
        else:
            discipline = self.discipline

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        default_venue_id: Union[None, Unset, str]
        if isinstance(self.default_venue_id, Unset):
            default_venue_id = UNSET
        elif isinstance(self.default_venue_id, UUID):
            default_venue_id = str(self.default_venue_id)
        else:
            default_venue_id = self.default_venue_id

        alternate_venue_ids: Union[Unset, list[str]] = UNSET
        if not isinstance(self.alternate_venue_ids, Unset):
            alternate_venue_ids = []
            for alternate_venue_ids_item_data in self.alternate_venue_ids:
                alternate_venue_ids_item = str(alternate_venue_ids_item_data)
                alternate_venue_ids.append(alternate_venue_ids_item)

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if international_reference is not UNSET:
            field_dict["internationalReference"] = international_reference
        if status is not UNSET:
            field_dict["status"] = status
        if name_full_local is not UNSET:
            field_dict["nameFullLocal"] = name_full_local
        if additional_names is not UNSET:
            field_dict["additionalNames"] = additional_names
        if name_full_latin is not UNSET:
            field_dict["nameFullLatin"] = name_full_latin
        if code_local is not UNSET:
            field_dict["codeLocal"] = code_local
        if code_latin is not UNSET:
            field_dict["codeLatin"] = code_latin
        if address is not UNSET:
            field_dict["address"] = address
        if social is not UNSET:
            field_dict["social"] = social
        if contacts is not UNSET:
            field_dict["contacts"] = contacts
        if details is not UNSET:
            field_dict["details"] = details
        if colors is not UNSET:
            field_dict["colors"] = colors
        if historical_names is not UNSET:
            field_dict["historicalNames"] = historical_names
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if age_group is not UNSET:
            field_dict["ageGroup"] = age_group
        if gender is not UNSET:
            field_dict["gender"] = gender
        if standard is not UNSET:
            field_dict["standard"] = standard
        if grade is not UNSET:
            field_dict["grade"] = grade
        if representing is not UNSET:
            field_dict["representing"] = representing
        if discipline is not UNSET:
            field_dict["discipline"] = discipline
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if default_venue_id is not UNSET:
            field_dict["defaultVenueId"] = default_venue_id
        if alternate_venue_ids is not UNSET:
            field_dict["alternateVenueIds"] = alternate_venue_ids
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.images_model import ImagesModel
        from ..models.team_model_additional_names import TeamModelAdditionalNames
        from ..models.team_model_colors import TeamModelColors
        from ..models.team_model_contact_details import TeamModelContactDetails
        from ..models.team_model_entity_additional_details import TeamModelEntityAdditionalDetails
        from ..models.team_model_entity_group import TeamModelEntityGroup
        from ..models.team_model_organization import TeamModelOrganization
        from ..models.team_model_social_media import TeamModelSocialMedia
        from ..models.team_model_team_address import TeamModelTeamAddress
        from ..models.team_model_team_historical_name import TeamModelTeamHistoricalName

        d = dict(src_dict)
        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, TeamModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = TeamModelOrganization.from_dict(_organization)

        def _parse_entity_group_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_group_id_type_0 = UUID(data)

                return entity_group_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_group_id = _parse_entity_group_id(d.pop("entityGroupId", UNSET))

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, TeamModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = TeamModelEntityGroup.from_dict(_entity_group)

        def _parse_international_reference(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        international_reference = _parse_international_reference(d.pop("internationalReference", UNSET))

        _status = d.pop("status", UNSET)
        status: Union[Unset, TeamModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = TeamModelStatus(_status)

        name_full_local = d.pop("nameFullLocal", UNSET)

        _additional_names = d.pop("additionalNames", UNSET)
        additional_names: Union[Unset, TeamModelAdditionalNames]
        if isinstance(_additional_names, Unset):
            additional_names = UNSET
        else:
            additional_names = TeamModelAdditionalNames.from_dict(_additional_names)

        def _parse_name_full_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_full_latin = _parse_name_full_latin(d.pop("nameFullLatin", UNSET))

        def _parse_code_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        code_local = _parse_code_local(d.pop("codeLocal", UNSET))

        def _parse_code_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        code_latin = _parse_code_latin(d.pop("codeLatin", UNSET))

        def _parse_address(data: object) -> Union["TeamModelTeamAddress", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                address_type_0 = TeamModelTeamAddress.from_dict(data)

                return address_type_0
            except:  # noqa: E722
                pass
            return cast(Union["TeamModelTeamAddress", None, Unset], data)

        address = _parse_address(d.pop("address", UNSET))

        def _parse_social(data: object) -> Union["TeamModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = TeamModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["TeamModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_contacts(data: object) -> Union["TeamModelContactDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                contacts_type_0 = TeamModelContactDetails.from_dict(data)

                return contacts_type_0
            except:  # noqa: E722
                pass
            return cast(Union["TeamModelContactDetails", None, Unset], data)

        contacts = _parse_contacts(d.pop("contacts", UNSET))

        def _parse_details(data: object) -> Union["TeamModelEntityAdditionalDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                details_type_0 = TeamModelEntityAdditionalDetails.from_dict(data)

                return details_type_0
            except:  # noqa: E722
                pass
            return cast(Union["TeamModelEntityAdditionalDetails", None, Unset], data)

        details = _parse_details(d.pop("details", UNSET))

        _colors = d.pop("colors", UNSET)
        colors: Union[Unset, TeamModelColors]
        if isinstance(_colors, Unset):
            colors = UNSET
        else:
            colors = TeamModelColors.from_dict(_colors)

        def _parse_historical_names(data: object) -> Union[None, Unset, list["TeamModelTeamHistoricalName"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                historical_names_type_0 = []
                _historical_names_type_0 = data
                for historical_names_type_0_item_data in _historical_names_type_0:
                    historical_names_type_0_item = TeamModelTeamHistoricalName.from_dict(
                        historical_names_type_0_item_data
                    )

                    historical_names_type_0.append(historical_names_type_0_item)

                return historical_names_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["TeamModelTeamHistoricalName"]], data)

        historical_names = _parse_historical_names(d.pop("historicalNames", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        def _parse_age_group(
            data: object,
        ) -> Union[None, TeamModelAgeGroupType1, TeamModelAgeGroupType2Type1, TeamModelAgeGroupType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                age_group_type_1 = TeamModelAgeGroupType1(data)

                return age_group_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                age_group_type_2_type_1 = TeamModelAgeGroupType2Type1(data)

                return age_group_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                age_group_type_3_type_1 = TeamModelAgeGroupType3Type1(data)

                return age_group_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[None, TeamModelAgeGroupType1, TeamModelAgeGroupType2Type1, TeamModelAgeGroupType3Type1, Unset],
                data,
            )

        age_group = _parse_age_group(d.pop("ageGroup", UNSET))

        def _parse_gender(
            data: object,
        ) -> Union[None, TeamModelGenderType1, TeamModelGenderType2Type1, TeamModelGenderType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                gender_type_1 = TeamModelGenderType1(data)

                return gender_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                gender_type_2_type_1 = TeamModelGenderType2Type1(data)

                return gender_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                gender_type_3_type_1 = TeamModelGenderType3Type1(data)

                return gender_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[None, TeamModelGenderType1, TeamModelGenderType2Type1, TeamModelGenderType3Type1, Unset], data
            )

        gender = _parse_gender(d.pop("gender", UNSET))

        def _parse_standard(
            data: object,
        ) -> Union[None, TeamModelStandardType1, TeamModelStandardType2Type1, TeamModelStandardType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                standard_type_1 = TeamModelStandardType1(data)

                return standard_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                standard_type_2_type_1 = TeamModelStandardType2Type1(data)

                return standard_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                standard_type_3_type_1 = TeamModelStandardType3Type1(data)

                return standard_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[None, TeamModelStandardType1, TeamModelStandardType2Type1, TeamModelStandardType3Type1, Unset],
                data,
            )

        standard = _parse_standard(d.pop("standard", UNSET))

        def _parse_grade(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        grade = _parse_grade(d.pop("grade", UNSET))

        def _parse_representing(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        representing = _parse_representing(d.pop("representing", UNSET))

        def _parse_discipline(
            data: object,
        ) -> Union[None, TeamModelDisciplineType1, TeamModelDisciplineType2Type1, TeamModelDisciplineType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_1 = TeamModelDisciplineType1(data)

                return discipline_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_2_type_1 = TeamModelDisciplineType2Type1(data)

                return discipline_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                discipline_type_3_type_1 = TeamModelDisciplineType3Type1(data)

                return discipline_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    None, TeamModelDisciplineType1, TeamModelDisciplineType2Type1, TeamModelDisciplineType3Type1, Unset
                ],
                data,
            )

        discipline = _parse_discipline(d.pop("discipline", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        def _parse_default_venue_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                default_venue_id_type_0 = UUID(data)

                return default_venue_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        default_venue_id = _parse_default_venue_id(d.pop("defaultVenueId", UNSET))

        alternate_venue_ids = []
        _alternate_venue_ids = d.pop("alternateVenueIds", UNSET)
        for alternate_venue_ids_item_data in _alternate_venue_ids or []:
            alternate_venue_ids_item = UUID(alternate_venue_ids_item_data)

            alternate_venue_ids.append(alternate_venue_ids_item)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        team_model = cls(
            entity_id=entity_id,
            organization_id=organization_id,
            organization=organization,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            international_reference=international_reference,
            status=status,
            name_full_local=name_full_local,
            additional_names=additional_names,
            name_full_latin=name_full_latin,
            code_local=code_local,
            code_latin=code_latin,
            address=address,
            social=social,
            contacts=contacts,
            details=details,
            colors=colors,
            historical_names=historical_names,
            external_id=external_id,
            age_group=age_group,
            gender=gender,
            standard=standard,
            grade=grade,
            representing=representing,
            discipline=discipline,
            updated=updated,
            added=added,
            default_venue_id=default_venue_id,
            alternate_venue_ids=alternate_venue_ids,
            images=images,
        )

        return team_model



from enum import Enum


class MatchProfilesModelMatchProfileConfigurationMatchRolesItem(str, Enum):
    ASSISTANT_REFEREE_1 = "ASSISTANT_REFEREE_1"
    ASSISTANT_REFEREE_2 = "ASSISTANT_REFEREE_2"
    DELEGATE = "DELEGATE"
    LIAISON_OFFICER = "LIAISON_OFFICER"
    MATCH_LIAISON = "MATCH_LIAISON"
    MATCH_SUPERVISOR = "MATCH_SUPERVISOR"
    OFFICE_STAFF = "OFFICE_STAFF"
    REFEREE = "REFEREE"
    REFEREE_LIAISON = "REFEREE_LIAISON"
    REFEREE_OBSERVER = "REFEREE_OBSERVER"
    REFEREE_OBSERVER_LIAISON = "REFEREE_OBSERVER_LIAISON"
    SCOREKEEPER = "SCOREKEEPER"
    SCOUT_1 = "SCOUT_1"
    SCOUT_2 = "SCOUT_2"
    SCOUT_3 = "SCOUT_3"
    SCOUT_SUPERVISOR = "SCOUT_SUPERVISOR"
    SECRETARY = "SECRETARY"
    TIMEKEEPER = "TIMEKEEPER"
    YOUTH_COORDINATOR = "YOUTH_COORDINATOR"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class UniformsModelBaseType(str, Enum):
    ENTITY = "ENTITY"
    ENTITYGROUP = "ENTITYGROUP"
    PERSON = "PERSON"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.uniforms_model_base_type import UniformsModelBaseType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.images_model import ImagesModel
    from ..models.uniforms_model_organization import UniformsModelOrganization


T = TypeVar("T", bound="UniformsModel")


@_attrs_define
class UniformsModel:
    """
    Attributes:
        uniform_id (Union[Unset, UUID]): The unique identifier of the Uniform Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, UniformsModelOrganization]): The organization that this uniforms belongs to
        base_type (Union[Unset, UniformsModelBaseType]): The object that this uniform relates to
            >- `ENTITY` Entity
            >- `ENTITYGROUP` Entity Group
            >- `PERSON` Person
             Example: entity.
        base_id (Union[Unset, UUID]): The unique identifier of the object associated with this record. If the `baseType`
            is `ENTITY` then this would be the value of `entityId`. Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        name_local (Union[Unset, str]): The name of the uniforms in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: Test uniform.
        name_latin (Union[None, Unset, str]): The name of the uniforms in [latin](#section/Introduction/Character-Sets-
            and-Names) characters Example: Test uniform.
        date_from (Union[None, Unset, datetime.date]): Date the Uniform is valid from Example: 1978-08-24.
        date_to (Union[None, Unset, datetime.date]): Date the Uniform is valid until Example: 1978-08-24.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        images (Union[Unset, list['ImagesModel']]):
    """

    uniform_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "UniformsModelOrganization"] = UNSET
    base_type: Union[Unset, UniformsModelBaseType] = UNSET
    base_id: Union[Unset, UUID] = UNSET
    name_local: Union[Unset, str] = UNSET
    name_latin: Union[None, Unset, str] = UNSET
    date_from: Union[None, Unset, datetime.date] = UNSET
    date_to: Union[None, Unset, datetime.date] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        uniform_id: Union[Unset, str] = UNSET
        if not isinstance(self.uniform_id, Unset):
            uniform_id = str(self.uniform_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        base_type: Union[Unset, str] = UNSET
        if not isinstance(self.base_type, Unset):
            base_type = self.base_type.value

        base_id: Union[Unset, str] = UNSET
        if not isinstance(self.base_id, Unset):
            base_id = str(self.base_id)

        name_local = self.name_local

        name_latin: Union[None, Unset, str]
        if isinstance(self.name_latin, Unset):
            name_latin = UNSET
        else:
            name_latin = self.name_latin

        date_from: Union[None, Unset, str]
        if isinstance(self.date_from, Unset):
            date_from = UNSET
        elif isinstance(self.date_from, datetime.date):
            date_from = self.date_from.isoformat()
        else:
            date_from = self.date_from

        date_to: Union[None, Unset, str]
        if isinstance(self.date_to, Unset):
            date_to = UNSET
        elif isinstance(self.date_to, datetime.date):
            date_to = self.date_to.isoformat()
        else:
            date_to = self.date_to

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if uniform_id is not UNSET:
            field_dict["uniformId"] = uniform_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if base_type is not UNSET:
            field_dict["baseType"] = base_type
        if base_id is not UNSET:
            field_dict["baseId"] = base_id
        if name_local is not UNSET:
            field_dict["nameLocal"] = name_local
        if name_latin is not UNSET:
            field_dict["nameLatin"] = name_latin
        if date_from is not UNSET:
            field_dict["dateFrom"] = date_from
        if date_to is not UNSET:
            field_dict["dateTo"] = date_to
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.images_model import ImagesModel
        from ..models.uniforms_model_organization import UniformsModelOrganization

        d = dict(src_dict)
        _uniform_id = d.pop("uniformId", UNSET)
        uniform_id: Union[Unset, UUID]
        if isinstance(_uniform_id, Unset):
            uniform_id = UNSET
        else:
            uniform_id = UUID(_uniform_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, UniformsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = UniformsModelOrganization.from_dict(_organization)

        _base_type = d.pop("baseType", UNSET)
        base_type: Union[Unset, UniformsModelBaseType]
        if isinstance(_base_type, Unset):
            base_type = UNSET
        else:
            base_type = UniformsModelBaseType(_base_type)

        _base_id = d.pop("baseId", UNSET)
        base_id: Union[Unset, UUID]
        if isinstance(_base_id, Unset):
            base_id = UNSET
        else:
            base_id = UUID(_base_id)

        name_local = d.pop("nameLocal", UNSET)

        def _parse_name_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_latin = _parse_name_latin(d.pop("nameLatin", UNSET))

        def _parse_date_from(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_from_type_0 = isoparse(data).date()

                return date_from_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_from = _parse_date_from(d.pop("dateFrom", UNSET))

        def _parse_date_to(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_to_type_0 = isoparse(data).date()

                return date_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_to = _parse_date_to(d.pop("dateTo", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        uniforms_model = cls(
            uniform_id=uniform_id,
            organization_id=organization_id,
            organization=organization,
            base_type=base_type,
            base_id=base_id,
            name_local=name_local,
            name_latin=name_latin,
            date_from=date_from,
            date_to=date_to,
            external_id=external_id,
            updated=updated,
            added=added,
            images=images,
        )

        return uniforms_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SeasonModelSeasonConfiguration")


@_attrs_define
class SeasonModelSeasonConfiguration:
    """Season Configuration settings

    Attributes:
        period_break_duration (Union[Unset, float]):
        half_time_duration (Union[Unset, float]):
    """

    period_break_duration: Union[Unset, float] = UNSET
    half_time_duration: Union[Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        period_break_duration = self.period_break_duration

        half_time_duration = self.half_time_duration

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if period_break_duration is not UNSET:
            field_dict["periodBreakDuration"] = period_break_duration
        if half_time_duration is not UNSET:
            field_dict["halfTimeDuration"] = half_time_duration

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        period_break_duration = d.pop("periodBreakDuration", UNSET)

        half_time_duration = d.pop("halfTimeDuration", UNSET)

        season_model_season_configuration = cls(
            period_break_duration=period_break_duration,
            half_time_duration=half_time_duration,
        )

        return season_model_season_configuration



from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.venue_external_ids_detail_response_default import VenueExternalIdsDetailResponseDefault
from ...models.venue_external_ids_detail_venue_external_ids_response import (
    VenueExternalIdsDetailVenueExternalIdsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    venue_external_id: UUID,
    *,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["external"] = external

    params["fields"] = fields

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["offset"] = offset

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/venues/externalids/{venue_external_id}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]:
    if response.status_code == 200:
        response_200 = VenueExternalIdsDetailVenueExternalIdsResponse.from_dict(response.json())

        return response_200

    response_default = VenueExternalIdsDetailResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    venue_external_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Response[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]:
    """Get a venue external identifier details

     Detailed information about a specific venue external identifier

    Args:
        organization_id (str):  Example: b1a23.
        venue_external_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        venue_external_id=venue_external_id,
        external=external,
        fields=fields,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    venue_external_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Optional[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]:
    """Get a venue external identifier details

     Detailed information about a specific venue external identifier

    Args:
        organization_id (str):  Example: b1a23.
        venue_external_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]
    """

    return sync_detailed(
        organization_id=organization_id,
        venue_external_id=venue_external_id,
        client=client,
        external=external,
        fields=fields,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    venue_external_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Response[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]:
    """Get a venue external identifier details

     Detailed information about a specific venue external identifier

    Args:
        organization_id (str):  Example: b1a23.
        venue_external_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        venue_external_id=venue_external_id,
        external=external,
        fields=fields,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    venue_external_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Optional[Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]]:
    """Get a venue external identifier details

     Detailed information about a specific venue external identifier

    Args:
        organization_id (str):  Example: b1a23.
        venue_external_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[VenueExternalIdsDetailResponseDefault, VenueExternalIdsDetailVenueExternalIdsResponse]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            venue_external_id=venue_external_id,
            client=client,
            external=external,
            fields=fields,
            hide_null=hide_null,
            include=include,
            limit=limit,
            offset=offset,
        )
    ).parsed



from enum import Enum


class SeriesModelSeriesType(str, Enum):
    BEST_OF = "BEST_OF"
    HOME_AND_AWAY = "HOME_AND_AWAY"
    KNOCKOUT = "KNOCKOUT"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="TeamModelContactDetails")


@_attrs_define
class TeamModelContactDetails:
    """Public contact fields

    Attributes:
        fax (Union[None, Unset, str]): Fax number
        phone (Union[None, Unset, str]): Primary phone number
        phone_secondary (Union[None, Unset, str]): Secondary phone number
        email (Union[None, Unset, str]): Primary email address
    """

    fax: Union[None, Unset, str] = UNSET
    phone: Union[None, Unset, str] = UNSET
    phone_secondary: Union[None, Unset, str] = UNSET
    email: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        fax: Union[None, Unset, str]
        if isinstance(self.fax, Unset):
            fax = UNSET
        else:
            fax = self.fax

        phone: Union[None, Unset, str]
        if isinstance(self.phone, Unset):
            phone = UNSET
        else:
            phone = self.phone

        phone_secondary: Union[None, Unset, str]
        if isinstance(self.phone_secondary, Unset):
            phone_secondary = UNSET
        else:
            phone_secondary = self.phone_secondary

        email: Union[None, Unset, str]
        if isinstance(self.email, Unset):
            email = UNSET
        else:
            email = self.email

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if fax is not UNSET:
            field_dict["fax"] = fax
        if phone is not UNSET:
            field_dict["phone"] = phone
        if phone_secondary is not UNSET:
            field_dict["phoneSecondary"] = phone_secondary
        if email is not UNSET:
            field_dict["email"] = email

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_fax(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        fax = _parse_fax(d.pop("fax", UNSET))

        def _parse_phone(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        phone = _parse_phone(d.pop("phone", UNSET))

        def _parse_phone_secondary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        phone_secondary = _parse_phone_secondary(d.pop("phoneSecondary", UNSET))

        def _parse_email(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        email = _parse_email(d.pop("email", UNSET))

        team_model_contact_details = cls(
            fax=fax,
            phone=phone,
            phone_secondary=phone_secondary,
            email=email,
        )

        return team_model_contact_details



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.fixture_progression_model_fixture import FixtureProgressionModelFixture
    from ..models.fixture_progression_model_organization import FixtureProgressionModelOrganization
    from ..models.fixture_progression_model_season import FixtureProgressionModelSeason


T = TypeVar("T", bound="FixtureProgressionModel")


@_attrs_define
class FixtureProgressionModel:
    """
    Attributes:
        fixture_id (Union[Unset, UUID]): Source fixtureId Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, FixtureProgressionModelFixture]): The match
        to_fixture_id (Union[Unset, UUID]): Destination fixtureId Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, FixtureProgressionModelOrganization]): The organization that this
            ~fixture_progression~ belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, FixtureProgressionModelSeason]): The season linked to this record
        placing_after (Union[Unset, int]): Place after source match completion Example: 1.
        is_home (Union[Unset, bool]): Will this competitor be the 'home' team in the target match? Example: True.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
    """

    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "FixtureProgressionModelFixture"] = UNSET
    to_fixture_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "FixtureProgressionModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "FixtureProgressionModelSeason"] = UNSET
    placing_after: Union[Unset, int] = UNSET
    is_home: Union[Unset, bool] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    external_id: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        to_fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.to_fixture_id, Unset):
            to_fixture_id = str(self.to_fixture_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        placing_after = self.placing_after

        is_home = self.is_home

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if to_fixture_id is not UNSET:
            field_dict["toFixtureId"] = to_fixture_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if placing_after is not UNSET:
            field_dict["placingAfter"] = placing_after
        if is_home is not UNSET:
            field_dict["isHome"] = is_home
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if external_id is not UNSET:
            field_dict["externalId"] = external_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.fixture_progression_model_fixture import FixtureProgressionModelFixture
        from ..models.fixture_progression_model_organization import FixtureProgressionModelOrganization
        from ..models.fixture_progression_model_season import FixtureProgressionModelSeason

        d = dict(src_dict)
        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, FixtureProgressionModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = FixtureProgressionModelFixture.from_dict(_fixture)

        _to_fixture_id = d.pop("toFixtureId", UNSET)
        to_fixture_id: Union[Unset, UUID]
        if isinstance(_to_fixture_id, Unset):
            to_fixture_id = UNSET
        else:
            to_fixture_id = UUID(_to_fixture_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, FixtureProgressionModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = FixtureProgressionModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, FixtureProgressionModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = FixtureProgressionModelSeason.from_dict(_season)

        placing_after = d.pop("placingAfter", UNSET)

        is_home = d.pop("isHome", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        fixture_progression_model = cls(
            fixture_id=fixture_id,
            fixture=fixture,
            to_fixture_id=to_fixture_id,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            placing_after=placing_after,
            is_home=is_home,
            updated=updated,
            added=added,
            external_id=external_id,
        )

        return fixture_progression_model



from enum import Enum


class MatchModelBroadcastsBroadcastType(str, Enum):
    PAY_PER_VIEW = "PAY_PER_VIEW"
    RADIO = "RADIO"
    STREAMING_AUDIO = "STREAMING_AUDIO"
    STREAMING_VIDEO = "STREAMING_VIDEO"
    TV = "TV"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.fixture_live_summary_model_clock_information import FixtureLiveSummaryModelClockInformation
    from ..models.fixture_live_summary_model_information_per_entity import FixtureLiveSummaryModelInformationPerEntity
    from ..models.fixture_live_summary_model_status_information import FixtureLiveSummaryModelStatusInformation


T = TypeVar("T", bound="FixtureLiveSummaryModel")


@_attrs_define
class FixtureLiveSummaryModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: b1a23.
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entities (Union[Unset, FixtureLiveSummaryModelInformationPerEntity]): Entity information: scores, person
            information, etc.
        clock (Union[Unset, FixtureLiveSummaryModelClockInformation]): Clock information
        status (Union[Unset, FixtureLiveSummaryModelStatusInformation]): Status information
    """

    organization_id: Union[Unset, str] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    entities: Union[Unset, "FixtureLiveSummaryModelInformationPerEntity"] = UNSET
    clock: Union[Unset, "FixtureLiveSummaryModelClockInformation"] = UNSET
    status: Union[Unset, "FixtureLiveSummaryModelStatusInformation"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        organization_id = self.organization_id

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        entities: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entities, Unset):
            entities = self.entities.to_dict()

        clock: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.clock, Unset):
            clock = self.clock.to_dict()

        status: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if entities is not UNSET:
            field_dict["entities"] = entities
        if clock is not UNSET:
            field_dict["clock"] = clock
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.fixture_live_summary_model_clock_information import FixtureLiveSummaryModelClockInformation
        from ..models.fixture_live_summary_model_information_per_entity import (
            FixtureLiveSummaryModelInformationPerEntity,
        )
        from ..models.fixture_live_summary_model_status_information import FixtureLiveSummaryModelStatusInformation

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _entities = d.pop("entities", UNSET)
        entities: Union[Unset, FixtureLiveSummaryModelInformationPerEntity]
        if isinstance(_entities, Unset):
            entities = UNSET
        else:
            entities = FixtureLiveSummaryModelInformationPerEntity.from_dict(_entities)

        _clock = d.pop("clock", UNSET)
        clock: Union[Unset, FixtureLiveSummaryModelClockInformation]
        if isinstance(_clock, Unset):
            clock = UNSET
        else:
            clock = FixtureLiveSummaryModelClockInformation.from_dict(_clock)

        _status = d.pop("status", UNSET)
        status: Union[Unset, FixtureLiveSummaryModelStatusInformation]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = FixtureLiveSummaryModelStatusInformation.from_dict(_status)

        fixture_live_summary_model = cls(
            organization_id=organization_id,
            fixture_id=fixture_id,
            entities=entities,
            clock=clock,
            status=status,
        )

        return fixture_live_summary_model



from enum import Enum


class MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem(str, Enum):
    BLUE = "Blue"
    RED = "Red"
    YELLOW = "Yellow"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class MatchModelPracticeDrillTypeType1(str, Enum):
    DRILL = "DRILL"
    FITNESS = "FITNESS"
    GAME = "GAME"
    OTHER = "OTHER"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.seasonteam_placings_model_entity import SEASONTEAMPlacingsModelEntity
    from ..models.seasonteam_placings_model_organization import SEASONTEAMPlacingsModelOrganization
    from ..models.seasonteam_placings_model_season import SEASONTEAMPlacingsModelSeason


T = TypeVar("T", bound="SEASONTEAMPlacingsModel")


@_attrs_define
class SEASONTEAMPlacingsModel:
    """
    Attributes:
        placing_id (Union[Unset, UUID]): The unique identifier of the SEASON TEAM placing Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SEASONTEAMPlacingsModelOrganization]): The organization that this SEASON TEAM
            placings belongs to
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SEASONTEAMPlacingsModelSeason]): The season linked to this record
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, SEASONTEAMPlacingsModelEntity]): The team information
        result_place (Union[Unset, int]): Result place Example: 1.
        points (Union[None, Unset, int]): Points awarded Example: 1.
        prize_money (Union[None, Unset, int]): Prize money awarded Example: 1.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    placing_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SEASONTEAMPlacingsModelOrganization"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SEASONTEAMPlacingsModelSeason"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "SEASONTEAMPlacingsModelEntity"] = UNSET
    result_place: Union[Unset, int] = UNSET
    points: Union[None, Unset, int] = UNSET
    prize_money: Union[None, Unset, int] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        placing_id: Union[Unset, str] = UNSET
        if not isinstance(self.placing_id, Unset):
            placing_id = str(self.placing_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        result_place = self.result_place

        points: Union[None, Unset, int]
        if isinstance(self.points, Unset):
            points = UNSET
        else:
            points = self.points

        prize_money: Union[None, Unset, int]
        if isinstance(self.prize_money, Unset):
            prize_money = UNSET
        else:
            prize_money = self.prize_money

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if placing_id is not UNSET:
            field_dict["placingId"] = placing_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if result_place is not UNSET:
            field_dict["resultPlace"] = result_place
        if points is not UNSET:
            field_dict["points"] = points
        if prize_money is not UNSET:
            field_dict["prizeMoney"] = prize_money
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.seasonteam_placings_model_entity import SEASONTEAMPlacingsModelEntity
        from ..models.seasonteam_placings_model_organization import SEASONTEAMPlacingsModelOrganization
        from ..models.seasonteam_placings_model_season import SEASONTEAMPlacingsModelSeason

        d = dict(src_dict)
        _placing_id = d.pop("placingId", UNSET)
        placing_id: Union[Unset, UUID]
        if isinstance(_placing_id, Unset):
            placing_id = UNSET
        else:
            placing_id = UUID(_placing_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SEASONTEAMPlacingsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SEASONTEAMPlacingsModelOrganization.from_dict(_organization)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SEASONTEAMPlacingsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SEASONTEAMPlacingsModelSeason.from_dict(_season)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, SEASONTEAMPlacingsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = SEASONTEAMPlacingsModelEntity.from_dict(_entity)

        result_place = d.pop("resultPlace", UNSET)

        def _parse_points(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        points = _parse_points(d.pop("points", UNSET))

        def _parse_prize_money(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        prize_money = _parse_prize_money(d.pop("prizeMoney", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        seasonteam_placings_model = cls(
            placing_id=placing_id,
            organization_id=organization_id,
            organization=organization,
            season_id=season_id,
            season=season,
            entity_id=entity_id,
            entity=entity,
            result_place=result_place,
            points=points,
            prize_money=prize_money,
            updated=updated,
            added=added,
        )

        return seasonteam_placings_model



import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.head_to_head_list_fixtures_mulitple_competitions_fixture_type import (
    HeadToHeadListFixturesMulitpleCompetitionsFixtureType,
)
from ...models.head_to_head_list_fixtures_mulitple_competitions_head_to_head_entity_response import (
    HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
)
from ...models.head_to_head_list_fixtures_mulitple_competitions_response_default import (
    HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
)
from ...models.head_to_head_list_fixtures_mulitple_competitions_status import (
    HeadToHeadListFixturesMulitpleCompetitionsStatus,
)
from ...models.head_to_head_list_fixtures_mulitple_competitions_status_not import (
    HeadToHeadListFixturesMulitpleCompetitionsStatusNot,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    person_id_1: UUID,
    person_id_2: UUID,
    *,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_ids: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_ids: Union[Unset, UUID] = UNSET,
    status: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus] = UNSET,
    status_not: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_added: Union[Unset, str] = UNSET
    if not isinstance(added, Unset):
        json_added = added.isoformat()
    params["added"] = json_added

    json_competition_ids: Union[Unset, str] = UNSET
    if not isinstance(competition_ids, Unset):
        json_competition_ids = str(competition_ids)
    params["competitionIds"] = json_competition_ids

    params["external"] = external

    params["fields"] = fields

    json_fixture_type: Union[Unset, str] = UNSET
    if not isinstance(fixture_type, Unset):
        json_fixture_type = fixture_type.value

    params["fixtureType"] = json_fixture_type

    json_from_time_local: Union[Unset, str] = UNSET
    if not isinstance(from_time_local, Unset):
        json_from_time_local = from_time_local.isoformat()
    params["fromTimeLocal"] = json_from_time_local

    json_from_time_utc: Union[Unset, str] = UNSET
    if not isinstance(from_time_utc, Unset):
        json_from_time_utc = from_time_utc.isoformat()
    params["fromTimeUTC"] = json_from_time_utc

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["offset"] = offset

    json_season_id: Union[Unset, str] = UNSET
    if not isinstance(season_id, Unset):
        json_season_id = str(season_id)
    params["seasonId"] = json_season_id

    json_season_ids: Union[Unset, str] = UNSET
    if not isinstance(season_ids, Unset):
        json_season_ids = str(season_ids)
    params["seasonIds"] = json_season_ids

    json_status: Union[Unset, str] = UNSET
    if not isinstance(status, Unset):
        json_status = status.value

    params["status"] = json_status

    json_status_not: Union[Unset, str] = UNSET
    if not isinstance(status_not, Unset):
        json_status_not = status_not.value

    params["statusNot"] = json_status_not

    json_to_time_local: Union[Unset, str] = UNSET
    if not isinstance(to_time_local, Unset):
        json_to_time_local = to_time_local.isoformat()
    params["toTimeLocal"] = json_to_time_local

    json_to_time_utc: Union[Unset, str] = UNSET
    if not isinstance(to_time_utc, Unset):
        json_to_time_utc = to_time_utc.isoformat()
    params["toTimeUTC"] = json_to_time_utc

    json_updated: Union[Unset, str] = UNSET
    if not isinstance(updated, Unset):
        json_updated = updated.isoformat()
    params["updated"] = json_updated

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/headToHead/fixtures/persons/{person_id_1}/{person_id_2}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[
    HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
    HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
]:
    if response.status_code == 200:
        response_200 = HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse.from_dict(response.json())

        return response_200

    response_default = HeadToHeadListFixturesMulitpleCompetitionsResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[
    Union[
        HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
        HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
    ]
]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    person_id_1: UUID,
    person_id_2: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_ids: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_ids: Union[Unset, UUID] = UNSET,
    status: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus] = UNSET,
    status_not: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Response[
    Union[
        HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
        HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
    ]
]:
    """Match History for head-to-head of two teams across multiple seasons or competitions

     Return the Matches for a two specific teams in multiple seasons or competitions.

    Args:
        organization_id (str):  Example: b1a23.
        person_id_1 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person_id_2 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType]):
            Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        status (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus]):  Example:
            SCHEDULED.
        status_not (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot]):  Example:
            SCHEDULED.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse, HeadToHeadListFixturesMulitpleCompetitionsResponseDefault]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        person_id_1=person_id_1,
        person_id_2=person_id_2,
        added=added,
        competition_ids=competition_ids,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        season_id=season_id,
        season_ids=season_ids,
        status=status,
        status_not=status_not,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        updated=updated,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    person_id_1: UUID,
    person_id_2: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_ids: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_ids: Union[Unset, UUID] = UNSET,
    status: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus] = UNSET,
    status_not: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Optional[
    Union[
        HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
        HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
    ]
]:
    """Match History for head-to-head of two teams across multiple seasons or competitions

     Return the Matches for a two specific teams in multiple seasons or competitions.

    Args:
        organization_id (str):  Example: b1a23.
        person_id_1 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person_id_2 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType]):
            Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        status (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus]):  Example:
            SCHEDULED.
        status_not (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot]):  Example:
            SCHEDULED.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse, HeadToHeadListFixturesMulitpleCompetitionsResponseDefault]
    """

    return sync_detailed(
        organization_id=organization_id,
        person_id_1=person_id_1,
        person_id_2=person_id_2,
        client=client,
        added=added,
        competition_ids=competition_ids,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        season_id=season_id,
        season_ids=season_ids,
        status=status,
        status_not=status_not,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        updated=updated,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    person_id_1: UUID,
    person_id_2: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_ids: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_ids: Union[Unset, UUID] = UNSET,
    status: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus] = UNSET,
    status_not: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Response[
    Union[
        HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
        HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
    ]
]:
    """Match History for head-to-head of two teams across multiple seasons or competitions

     Return the Matches for a two specific teams in multiple seasons or competitions.

    Args:
        organization_id (str):  Example: b1a23.
        person_id_1 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person_id_2 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType]):
            Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        status (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus]):  Example:
            SCHEDULED.
        status_not (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot]):  Example:
            SCHEDULED.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse, HeadToHeadListFixturesMulitpleCompetitionsResponseDefault]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        person_id_1=person_id_1,
        person_id_2=person_id_2,
        added=added,
        competition_ids=competition_ids,
        external=external,
        fields=fields,
        fixture_type=fixture_type,
        from_time_local=from_time_local,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        season_id=season_id,
        season_ids=season_ids,
        status=status,
        status_not=status_not,
        to_time_local=to_time_local,
        to_time_utc=to_time_utc,
        updated=updated,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    person_id_1: UUID,
    person_id_2: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_ids: Union[Unset, UUID] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    fixture_type: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType] = UNSET,
    from_time_local: Union[Unset, datetime.datetime] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    season_ids: Union[Unset, UUID] = UNSET,
    status: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus] = UNSET,
    status_not: Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot] = UNSET,
    to_time_local: Union[Unset, datetime.datetime] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Optional[
    Union[
        HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
        HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
    ]
]:
    """Match History for head-to-head of two teams across multiple seasons or competitions

     Return the Matches for a two specific teams in multiple seasons or competitions.

    Args:
        organization_id (str):  Example: b1a23.
        person_id_1 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person_id_2 (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        fixture_type (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsFixtureType]):
            Example: REGULAR.
        from_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_ids (Union[Unset, UUID]):  Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc,de83c6a8-3b29-11eb-bdb7-0242ac130005.
        status (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatus]):  Example:
            SCHEDULED.
        status_not (Union[Unset, HeadToHeadListFixturesMulitpleCompetitionsStatusNot]):  Example:
            SCHEDULED.
        to_time_local (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse, HeadToHeadListFixturesMulitpleCompetitionsResponseDefault]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            person_id_1=person_id_1,
            person_id_2=person_id_2,
            client=client,
            added=added,
            competition_ids=competition_ids,
            external=external,
            fields=fields,
            fixture_type=fixture_type,
            from_time_local=from_time_local,
            from_time_utc=from_time_utc,
            hide_null=hide_null,
            include=include,
            limit=limit,
            offset=offset,
            season_id=season_id,
            season_ids=season_ids,
            status=status,
            status_not=status_not,
            to_time_local=to_time_local,
            to_time_utc=to_time_utc,
            updated=updated,
        )
    ).parsed



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.error_model import ErrorModel
    from ..models.response_meta_data import ResponseMetaData


T = TypeVar("T", bound="DivisionDetailResponseDefault")


@_attrs_define
class DivisionDetailResponseDefault:
    """
    Attributes:
        meta (Union[Unset, ResponseMetaData]):
        error (Union[Unset, ErrorModel]):
    """

    meta: Union[Unset, "ResponseMetaData"] = UNSET
    error: Union[Unset, "ErrorModel"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        meta: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.meta, Unset):
            meta = self.meta.to_dict()

        error: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if meta is not UNSET:
            field_dict["meta"] = meta
        if error is not UNSET:
            field_dict["error"] = error

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.error_model import ErrorModel
        from ..models.response_meta_data import ResponseMetaData

        d = dict(src_dict)
        _meta = d.pop("meta", UNSET)
        meta: Union[Unset, ResponseMetaData]
        if isinstance(_meta, Unset):
            meta = UNSET
        else:
            meta = ResponseMetaData.from_dict(_meta)

        _error = d.pop("error", UNSET)
        error: Union[Unset, ErrorModel]
        if isinstance(_error, Unset):
            error = UNSET
        else:
            error = ErrorModel.from_dict(_error)

        division_detail_response_default = cls(
            meta=meta,
            error=error,
        )

        division_detail_response_default.additional_properties = d
        return division_detail_response_default

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ConductModelConductTypeItem(str, Enum):
    CITATION = "CITATION"
    CONCUSSION = "CONCUSSION"
    CORRUPTION = "CORRUPTION"
    DOPING = "DOPING"
    MATCH_FIXING = "MATCH_FIXING"
    SWEARING = "SWEARING"
    UNSPORTSMANLIKE_CONDUCT = "UNSPORTSMANLIKE_CONDUCT"
    VIOLENT_CONDUCT = "VIOLENT_CONDUCT"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class SeriesModelStatus(str, Enum):
    ACTIVE = "ACTIVE"
    COMPLETE = "COMPLETE"
    NOT_STARTED = "NOT_STARTED"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class VideoFileModelStatusType3Type1(str, Enum):
    AVAILABLE = "AVAILABLE"
    BUILDABLE = "BUILDABLE"
    PENDING = "PENDING"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.match_model_match_competitor_result_status import MatchModelMatchCompetitorResultStatus
from ..models.match_model_match_competitor_roster_status import MatchModelMatchCompetitorRosterStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="MatchModelMatchCompetitor")


@_attrs_define
class MatchModelMatchCompetitor:
    """
    Attributes:
        entity_id (str): The uuid of the entity
        conference_id (Union[Unset, str]): The uuid of the conference
        division_id (Union[Unset, str]): The uuid of the division
        include_in_conference_statistics (Union[Unset, bool]): Include the statistics for this competitors in the
            conference statistics?
        is_home (Union[Unset, bool]): Is competitor the home team ?
        include_in_representation (Union[Unset, bool]): Include participant in representation count
        draw (Union[Unset, bool]): Result for this competitor was a draw ?
        result_status (Union[Unset, MatchModelMatchCompetitorResultStatus]): Result status
        result_place (Union[None, Unset, float]): Result placing (1=Won, 2=Lost)
        result_secondary_score_place (Union[None, Unset, float]): Secondary Score Result placing (1=Won, 2=Lost)
        starting_number (Union[None, Unset, float]): Starting number
        score (Union[None, Unset, str]): Score for competitor in match
        secondary_score (Union[None, Unset, str]): Secondary score
        shoot_out_attempts (Union[None, Unset, str]): shootOut Attempts
        roster_status (Union[Unset, MatchModelMatchCompetitorRosterStatus]): Roster status
        is_neutral_venue (Union[Unset, bool]): Competitor is playing at a neutral venue ?
        uniform_id (Union[None, Unset, str]): The uuid of the uniform
        external_id (Union[Unset, str]): externalId
    """

    entity_id: str
    conference_id: Union[Unset, str] = UNSET
    division_id: Union[Unset, str] = UNSET
    include_in_conference_statistics: Union[Unset, bool] = UNSET
    is_home: Union[Unset, bool] = UNSET
    include_in_representation: Union[Unset, bool] = UNSET
    draw: Union[Unset, bool] = UNSET
    result_status: Union[Unset, MatchModelMatchCompetitorResultStatus] = UNSET
    result_place: Union[None, Unset, float] = UNSET
    result_secondary_score_place: Union[None, Unset, float] = UNSET
    starting_number: Union[None, Unset, float] = UNSET
    score: Union[None, Unset, str] = UNSET
    secondary_score: Union[None, Unset, str] = UNSET
    shoot_out_attempts: Union[None, Unset, str] = UNSET
    roster_status: Union[Unset, MatchModelMatchCompetitorRosterStatus] = UNSET
    is_neutral_venue: Union[Unset, bool] = UNSET
    uniform_id: Union[None, Unset, str] = UNSET
    external_id: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        entity_id = self.entity_id

        conference_id = self.conference_id

        division_id = self.division_id

        include_in_conference_statistics = self.include_in_conference_statistics

        is_home = self.is_home

        include_in_representation = self.include_in_representation

        draw = self.draw

        result_status: Union[Unset, str] = UNSET
        if not isinstance(self.result_status, Unset):
            result_status = self.result_status.value

        result_place: Union[None, Unset, float]
        if isinstance(self.result_place, Unset):
            result_place = UNSET
        else:
            result_place = self.result_place

        result_secondary_score_place: Union[None, Unset, float]
        if isinstance(self.result_secondary_score_place, Unset):
            result_secondary_score_place = UNSET
        else:
            result_secondary_score_place = self.result_secondary_score_place

        starting_number: Union[None, Unset, float]
        if isinstance(self.starting_number, Unset):
            starting_number = UNSET
        else:
            starting_number = self.starting_number

        score: Union[None, Unset, str]
        if isinstance(self.score, Unset):
            score = UNSET
        else:
            score = self.score

        secondary_score: Union[None, Unset, str]
        if isinstance(self.secondary_score, Unset):
            secondary_score = UNSET
        else:
            secondary_score = self.secondary_score

        shoot_out_attempts: Union[None, Unset, str]
        if isinstance(self.shoot_out_attempts, Unset):
            shoot_out_attempts = UNSET
        else:
            shoot_out_attempts = self.shoot_out_attempts

        roster_status: Union[Unset, str] = UNSET
        if not isinstance(self.roster_status, Unset):
            roster_status = self.roster_status.value

        is_neutral_venue = self.is_neutral_venue

        uniform_id: Union[None, Unset, str]
        if isinstance(self.uniform_id, Unset):
            uniform_id = UNSET
        else:
            uniform_id = self.uniform_id

        external_id = self.external_id

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "entityId": entity_id,
            }
        )
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if include_in_conference_statistics is not UNSET:
            field_dict["includeInConferenceStatistics"] = include_in_conference_statistics
        if is_home is not UNSET:
            field_dict["isHome"] = is_home
        if include_in_representation is not UNSET:
            field_dict["includeInRepresentation"] = include_in_representation
        if draw is not UNSET:
            field_dict["draw"] = draw
        if result_status is not UNSET:
            field_dict["resultStatus"] = result_status
        if result_place is not UNSET:
            field_dict["resultPlace"] = result_place
        if result_secondary_score_place is not UNSET:
            field_dict["resultSecondaryScorePlace"] = result_secondary_score_place
        if starting_number is not UNSET:
            field_dict["startingNumber"] = starting_number
        if score is not UNSET:
            field_dict["score"] = score
        if secondary_score is not UNSET:
            field_dict["secondaryScore"] = secondary_score
        if shoot_out_attempts is not UNSET:
            field_dict["shootOutAttempts"] = shoot_out_attempts
        if roster_status is not UNSET:
            field_dict["rosterStatus"] = roster_status
        if is_neutral_venue is not UNSET:
            field_dict["isNeutralVenue"] = is_neutral_venue
        if uniform_id is not UNSET:
            field_dict["uniformId"] = uniform_id
        if external_id is not UNSET:
            field_dict["externalId"] = external_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        entity_id = d.pop("entityId")

        conference_id = d.pop("conferenceId", UNSET)

        division_id = d.pop("divisionId", UNSET)

        include_in_conference_statistics = d.pop("includeInConferenceStatistics", UNSET)

        is_home = d.pop("isHome", UNSET)

        include_in_representation = d.pop("includeInRepresentation", UNSET)

        draw = d.pop("draw", UNSET)

        _result_status = d.pop("resultStatus", UNSET)
        result_status: Union[Unset, MatchModelMatchCompetitorResultStatus]
        if isinstance(_result_status, Unset):
            result_status = UNSET
        else:
            result_status = MatchModelMatchCompetitorResultStatus(_result_status)

        def _parse_result_place(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        result_place = _parse_result_place(d.pop("resultPlace", UNSET))

        def _parse_result_secondary_score_place(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        result_secondary_score_place = _parse_result_secondary_score_place(d.pop("resultSecondaryScorePlace", UNSET))

        def _parse_starting_number(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        starting_number = _parse_starting_number(d.pop("startingNumber", UNSET))

        def _parse_score(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        score = _parse_score(d.pop("score", UNSET))

        def _parse_secondary_score(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        secondary_score = _parse_secondary_score(d.pop("secondaryScore", UNSET))

        def _parse_shoot_out_attempts(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        shoot_out_attempts = _parse_shoot_out_attempts(d.pop("shootOutAttempts", UNSET))

        _roster_status = d.pop("rosterStatus", UNSET)
        roster_status: Union[Unset, MatchModelMatchCompetitorRosterStatus]
        if isinstance(_roster_status, Unset):
            roster_status = UNSET
        else:
            roster_status = MatchModelMatchCompetitorRosterStatus(_roster_status)

        is_neutral_venue = d.pop("isNeutralVenue", UNSET)

        def _parse_uniform_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        uniform_id = _parse_uniform_id(d.pop("uniformId", UNSET))

        external_id = d.pop("externalId", UNSET)

        match_model_match_competitor = cls(
            entity_id=entity_id,
            conference_id=conference_id,
            division_id=division_id,
            include_in_conference_statistics=include_in_conference_statistics,
            is_home=is_home,
            include_in_representation=include_in_representation,
            draw=draw,
            result_status=result_status,
            result_place=result_place,
            result_secondary_score_place=result_secondary_score_place,
            starting_number=starting_number,
            score=score,
            secondary_score=secondary_score,
            shoot_out_attempts=shoot_out_attempts,
            roster_status=roster_status,
            is_neutral_venue=is_neutral_venue,
            uniform_id=uniform_id,
            external_id=external_id,
        )

        return match_model_match_competitor



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.season_roster_model_entity_resource_type import SeasonRosterModelEntityResourceType
from ..types import UNSET, Unset

T = TypeVar("T", bound="SeasonRosterModelEntity")


@_attrs_define
class SeasonRosterModelEntity:
    """The team information

    Attributes:
        resource_type (Union[Unset, SeasonRosterModelEntityResourceType]):
        id (Union[Unset, str]): Unique identifier for this resource Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
    """

    resource_type: Union[Unset, SeasonRosterModelEntityResourceType] = UNSET
    id: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        resource_type: Union[Unset, str] = UNSET
        if not isinstance(self.resource_type, Unset):
            resource_type = self.resource_type.value

        id = self.id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if resource_type is not UNSET:
            field_dict["resourceType"] = resource_type
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _resource_type = d.pop("resourceType", UNSET)
        resource_type: Union[Unset, SeasonRosterModelEntityResourceType]
        if isinstance(_resource_type, Unset):
            resource_type = UNSET
        else:
            resource_type = SeasonRosterModelEntityResourceType(_resource_type)

        id = d.pop("id", UNSET)

        season_roster_model_entity = cls(
            resource_type=resource_type,
            id=id,
        )

        season_roster_model_entity.additional_properties = d
        return season_roster_model_entity

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
